"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;

var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));

var _utils = require("./utils");

/**
 * producing the immutable data with the given argument
 *
 * if object => recurse its children
 * if array => new List
 * if string => ''
 * if boolean => false
 * if number => 0
 * if toOne relation => null
 * if toMany relation => null
 * if dateTime => string
 */
function loop(schema) {
  var result; // $FlowFixMe

  if ((0, _typeof2.default)(schema) === 'object' && schema.defaultValue) {
    return (0, _utils.genDefaultValue)(schema.defaultValue);
  }

  switch (schema.type) {
    case 'object':
      result = (0, _utils.mapSchema)(schema.items, loop);
      result.__typename = result.__typename || null;
      break;

    case 'array':
      result = [];
      break;

    case 'number':
      result = 0;
      break;

    case 'geoPoint':
      result = {
        __typename: null,
        lat: 0,
        lng: 0,
        address: '',
        placeId: ''
      };
      break;

    case 'dateTime':
      result = '';
      break;

    case 'file':
      result = {
        __typename: null,
        contentType: '',
        size: 0,
        name: '',
        url: ''
      };
      break;

    case 'image':
      result = {
        __typename: null,
        contentType: '',
        size: 0,
        name: '',
        url: ''
      };
      break;

    case 'boolean':
      result = false;
      break;

    case 'string':
      result = '';
      break;

    case 'relation':
      {
        var type = schema.relation.type;

        switch (type) {
          case 'toMany':
            result = [];
            break;

          case 'toOne':
          default:
            result = null;
            break;
        }

        break;
      }

    case 'json':
      {
        result = {};
        break;
      }

    case 'component':
      {
        break;
      }

    case 'enum':
      result = '';
      break;

    default:
      throw new Error("unsupport type ".concat(schema.type));
      break;
  }

  return result;
}

function _default(schema) {
  if (!schema) {
    return null;
  }

  if ('type' in schema) {
    return loop(schema);
  }

  return (0, _utils.mapSchema)(schema, loop);
}